@@ -10,7 +10,7 @@
 
 #if defined(USE_MINIZIP) || defined(USE_MINIZIP_NG)
 #  ifdef USE_MINIZIP_NG
-#    include <mz_compat.h>
+#    include <minizip-ng/unzip.h>
 #  else
 #    include <minizip/unzip.h>
 #  endif
@@ -704,7 +704,10 @@ unzGetGlobalInfo(data->zip, &zipglobalinfo);
           buf[buflen - 1] = 0;
           while ((status = unzGetCurrentFileInfo(data->zip, NULL, buf, buflen, NULL, 0, NULL, 0)) == UNZ_OK && buf[buflen - 1] != 0) {
             buflen += UNZIP_FILENAME_BUFFER_STEP;
-            buf = (char*)realloc(buf, buflen);
+            if ((buf = (char*)realloc(buf, buflen)) == NULL) {
+              //memory allocation error
+              return;
+            }
             buf[buflen - 1] = 0;
           }
           if (status != UNZ_OK)
@@ -1625,7 +1628,7 @@ DLL_EXPORT_XLSXIO int xlsxioread_sheet_next_cell_datetime (xlsxioreadersheet she
     if (value != 0) {
       value = (value - 25569) * 86400;  //conversion from Excel to Unix timestamp
     }
-    *pvalue = value;
+    *pvalue = (time_t)value;
   }
   free(result);
   return 1;
